@@ -1,15 +1,20 @@
-import {ChangeDetectorRef, Component, Input, OnInit, ChangeDetectionStrategy} from "@angular/core";
-import {Router} from "@angular/router";
-import {ComponentLifecycleEventEmitter} from "@synerty/vortexjs";
+import {
+    ChangeDetectionStrategy,
+    ChangeDetectorRef,
+    Component,
+    Input
+} from "@angular/core"
+import { Router } from "@angular/router"
+import { NgLifeCycleEvents } from "@synerty/vortexjs"
 import {
     SearchObjectTypeTuple,
     SearchPropT,
     SearchResultObjectRouteTuple,
     SearchResultObjectTuple,
     SearchService
-} from "@peek/peek_core_search";
-import {searchPluginName} from "@peek/peek_core_search/_private";
-import {DocDbPopupService, DocDbPopupTypeE} from "@peek/peek_plugin_docdb";
+} from "@peek/peek_core_search"
+import { searchPluginName } from "@peek/peek_core_search/_private"
+import { DocDbPopupService, DocDbPopupTypeE } from "@peek/peek_core_docdb"
 import { BehaviorSubject } from "rxjs"
 
 interface IItemResult {
@@ -25,14 +30,24 @@ interface IObjectTypeResults {
 }
 
 @Component({
-    selector: "plugin-search-result",
-    templateUrl: "result.component.web.html",
-    styleUrls: ["result.component.web.scss"],
+    selector: "result-component",
+    templateUrl: "result.component.html",
+    styleUrls: ["result.component.scss"],
     changeDetection: ChangeDetectionStrategy.OnPush
 })
-export class ResultComponent extends ComponentLifecycleEventEmitter {
+export class ResultComponent extends NgLifeCycleEvents {
     @Input("firstSearchHasRun")
     firstSearchHasRun: boolean
+    resultObjectTypes$ = new BehaviorSubject<IObjectTypeResults[]>([])
+    
+    constructor(
+        private objectPopupService: DocDbPopupService,
+        private cdr: ChangeDetectorRef,
+        private router: Router,
+        private searchService: SearchService,
+    ) {
+        super()
+    }
     
     @Input("resultObjects")
     set resultObjects(resultObjects: SearchResultObjectTuple[]) {
@@ -78,17 +93,6 @@ export class ResultComponent extends ComponentLifecycleEventEmitter {
         }))
     }
     
-    resultObjectTypes$ = new BehaviorSubject<IObjectTypeResults[]>([])
-    
-    constructor(
-        private objectPopupService: DocDbPopupService,
-        private cdr: ChangeDetectorRef,
-        private router: Router,
-        private searchService: SearchService,
-    ) {
-        super()
-    }
-    
     headerProps(props: SearchPropT[]): string {
         return props.filter(p => p.showInHeader)
             .map(p => p.value)
